@@ -136,7 +136,7 @@ class CustomFormatter(logging.Formatter):
         if len(record.threadName) >= 12:
             record.threadName = record.threadName[-(12 - 3):] + '...'
         if len(record.name) >= 50:
-            record.name = record.name[-(50 - 3):] + '...'
+            record.name = '...' + record.name[-(50 - 3):]
         if len(record.funcName) >= 30:
             record.funcName = record.funcName[:30 - 3] + '...'
 
@@ -145,7 +145,7 @@ class CustomFormatter(logging.Formatter):
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}|{threadName:^12}|{lineno:^5}| {name:<50}|{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}|{threadName:^12}|{lineno:^5}| {name:<50} |{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
     handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up, maxBytes=10 * (1024 * 1024))
     handler.namer = std_namer
     handler.setFormatter(formatter)
